﻿using System.Configuration;
using System.Net.Http;
using System.Threading.Tasks;
using System.Web.Http;
using EnvelopeCreatorProject.Models;
using QuikESignTransport.SelfService.Classes;
using System;
using System.Net;

namespace QuikESignTransport.SelfService.Controllers
{
    public class SignController : ApiController
    {
        private readonly string _docusignAPIVersion = ConfigurationManager.AppSettings["DocusignAPIVersion"];
        private readonly string _docusignIntegratorKey = ConfigurationManager.AppSettings["DocusignIntegratorKey"];
        private readonly RequestHelper _helper;

        public SignController()
        {
            _helper = new RequestHelper();
        }

        [HttpPost]
        [Route("sign/selfservice")]
        public async Task<EnvelopeResult> SelfService(HttpRequestMessage request)
        {
            //1. Read posted data as a raw JSON string. 
            //   It is utterly important that this string is not manipulated for a successful transaction at Docusign
            var jsonString = await request.Content.ReadAsStringAsync();
            
            //2. Generate a token at Quik! in order to consume the REST service and generate the envelope
            var token = _helper.GenerateQuikToken();

            //3. Invoke the rest service that will return the necessary information that is needed for generating an envelope. This sample project uses the EnvelopeCreator dll for generating an envelope at Docusign.
            try
            {
                SelfServiceData envelopeData = _helper.GetEnvelopeData(jsonString, token);
                envelopeData.AccountAuthentication = _helper.GetDocusignAuthentication();

                EnvelopeResult envelopeCreatorResult = _helper.GenerateDocusignEnvelope(envelopeData, _docusignIntegratorKey, _docusignAPIVersion);
                //In envelopeCreatorResult.EnvelopeResponse you will find the Docusign full response, including the Envelope ID.

                //Return the EnvelopeResult instance so that the Quik! Forms Engine can read the result and notify the response to the user
                return envelopeCreatorResult;
            }
            catch (Exception e)
            {
                //returning error. Handle error
                throw new HttpResponseException(new HttpResponseMessage(HttpStatusCode.InternalServerError)
                {
                    Content = new StringContent("An error occurred, please try again or contact the administrator."),
                    ReasonPhrase = e.Message
                });
            }
            
        }
    }
}
