﻿using EnvelopeCreatorProject.DocusignAPI;
using System.Collections.Generic;
using QuikESignTransport.SelfService.Recipients.SignRecipients;

namespace QuikESignTransport.SelfService.Recipients
{
    public interface IRecipientSendTypeBuilder
    {
        void Build(Recipient recipient);
    }

    public class RecipientBuilder
    {
        public static IRecipientSendTypeBuilder GetSendTypeBuilder(SendType.Type type)
        {
            var _sendTypeBuilders = new Dictionary<SendType.Type, IRecipientSendTypeBuilder>()
            {
                { SendType.Type.EmailToSign, new EmailToSignRecipientBuilder() },
                { SendType.Type.SendCopy, new CarbonCopyRecipientBuilder() },
                { SendType.Type.InPersonSigners,new InPersonSignersRecipientBuilder() },
                { SendType.Type.Agents, new AgentsRecipientBuilder() },
                { SendType.Type.CertifiedDeliverY, new CertifiedDeliveriesRecipientBuilder() },
                { SendType.Type.Editors, new EditorRecipientBuilder() },
                { SendType.Type.Intermediaries, new IntermediariesRecipientBuilder() }
             };

            return _sendTypeBuilders.ContainsKey(type) ? _sendTypeBuilders[type] : new EmailToSignRecipientBuilder();
        }
    }
}